# Copyright 1999-2016. Parallels IP Holdings GmbH. All Rights Reserved.

import sys
import os
import shutil
import os.path
from plesk_atomic import comment_plesk_managed_directives, TORTIX_WAF_FILENAME, \
    run_aum_plesk_installer, prepare_ruleset_layout, fix_asl_config, deactivate_00_mod_security_conf,\
    run_aum, ASL_LICENSE, ASL_LICENSE_SAVED

unpaid_asl_license = "/var/lib/plesk/modsec/tortix-unpaid-license.key"


def check_asl_license():
    if os.path.isfile(ASL_LICENSE):
        return
    if not os.path.isdir("/etc/asl"):
        os.makedirs("/etc/asl", 0755)
    if os.path.isfile(ASL_LICENSE_SAVED):
        os.rename(ASL_LICENSE_SAVED, ASL_LICENSE)
    else:
        shutil.copyfile(unpaid_asl_license, ASL_LICENSE)


def main():
    try:
        ruleset_dir = sys.argv[2]

        check_asl_license()
        run_aum_plesk_installer()
        prepare_ruleset_layout(ruleset_dir)
        fix_asl_config(os.path.join(ruleset_dir, "modsec"))
        run_aum()
        comment_plesk_managed_directives(os.path.join(ruleset_dir, "modsec", TORTIX_WAF_FILENAME))
    except Exception as ex:
        sys.stderr.write("%s\n" % ex)
        sys.exit(1)
    finally:
        deactivate_00_mod_security_conf()


if __name__ == "__main__":
    main()

# vim: ts=4 sts=4 sw=4 et :
